OC.L10N.register(
    "groupfolders",
    {
    "Deny" : "Từ chối",
    "Allow" : "Cho phép",
    "Group" : "Nhóm",
    "Team" : "Đội",
    "Read" : "Đọc",
    "Create" : "Tạo mới",
    "Delete" : "Xóa",
    "Share" : "Chia sẻ",
    "You" : "Bạn",
    "Add group" : "Thêm nhóm",
    "Unlimited" : "Không giới hạn",
    "Folder name" : "Tên thư mục",
    "Quota" : "Hạn ngạch",
    "Previous" : "Trước",
    "Next" : "Tiếp theo",
    "User" : "Người dùng",
    "Unknown" : "Không xác định",
    "None" : "Không có",
    "{size} used" : "{size} đã sử dụng",
    "Unset" : "Bỏ cài đặt"
},
"nplurals=1; plural=0;");
